﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.IO;
using C1.Chart.Test;

namespace ChartBenchmark
{
    public partial class Form1 : Form
    {
        Charts charts = new Charts();
        ChartTests tests = new ChartTests(true);
        TestResultGroup[] res;

        public Form1()
        {
            InitializeComponent();
        }

        private void btnRun_Click(object sender, EventArgs e)
        {
            var items = listCharts.CheckedItems.OfType<string>().ToList();
            tests.Options.Controls = string.Join(",", items.ToArray());

            var frm = new Form() { Width = tests.Options.Width, Height = tests.Options.Height };
            frm.Shown += (s1,e1) =>
            {
                res = tests.RunGroup( (s) =>
                {
                    frm.Text = s;
                    frm.Controls.Clear();
                    var chart  = charts.CreateChart(s);
                    if (chart != null)
                    {
                        var ctrl = chart.GetControl() as Control;
                        if (ctrl != null)
                        {
                            ctrl.Margin = Padding.Empty;
                            ctrl.Dock = DockStyle.Fill;
                            frm.Controls.Add(ctrl);
                        }
                    }
                    return chart;
                }, (s) =>
                {
                    frm.Text = s;
                    return false;
                });

                var txt = SysInfo.GetInfo();
                foreach (var g in res)
                {
                    if(g!=null)
                        txt += g.Format();
                }

                textBox1.Text = txt;
                frm.Close();
            };
            frm.Show();
        }


        private void Form1_Load(object sender, EventArgs e)
        {
            propertyGrid1.SelectedObject = tests.Options;
            listCharts.Items.AddRange(charts.Names);
            listCharts.SetItemChecked(0, true);
            listCharts.SetItemChecked(1, true);
        }

        private void btnSave_Click(object sender, EventArgs e)
        {
            var dlg = new SaveFileDialog() { FileName = "results", DefaultExt = ".txt" };
            if (dlg.ShowDialog() == DialogResult.OK)
            {
                var txt = SysInfo.GetInfo();
                txt += "Name,Type,NPts,Time,StDev\r\n";
                foreach (var g in res)
                    txt += g.FormatCsv();
                File.WriteAllText(dlg.FileName, txt);
            }
        }
    }
}
