﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using C1.Chart.Test;
using C1.Chart;
using C1.Win.Chart;

namespace ChartBenchmark.Controls
{
    class FlexChartCtrl : C1.Chart.Test.IChart
    {
        FlexChart _chart;
        PlotType _ptype = PlotType.Column;

        public FlexChartCtrl()
        {
            _chart = CreateChart();
            _chart.SmoothingMode = ChartSmoothingMode.HighSpeed;
        }

        public PlotType PlotType
        {
            get
            {
                return _ptype;
            }

            set
            {
                _ptype = value;
            }
        }

        virtual protected FlexChart CreateChart()
        {
            return new FlexChart();
        }

        void SetPlotType()
        {
            switch (PlotType)
            {
                case PlotType.Column:
                    _chart.ChartType = ChartType.Column;
                    break;
                case PlotType.Line:
                    _chart.ChartType = ChartType.Line;
                    break;
                case PlotType.LineSymbols:
                    _chart.ChartType = ChartType.LineSymbols;
                    break;
                case PlotType.Scatter:
                    _chart.ChartType = ChartType.Scatter;
                    break;
                case PlotType.Area:
                    _chart.ChartType = ChartType.Area;
                    break;
            }
        }

        public void Clear()
        {
            _chart.Series.Clear();
            _chart.DataSource = null;
        }

        public void Create(ICollection<DataPoint> pts)
        {
            _chart.BeginUpdate();

            // create and setup series
            var ser = new Series();
            ser.Style.StrokeWidth = 1;
            ser.SymbolMarker = SymbolMarker.Box;
            ser.SymbolSize = 6;
            _chart.Series.Add(ser);

            // bind the chart to collection of points
            _chart.Binding = "Y";
            _chart.BindingX = "X";
            _chart.DataSource = pts;
           
            // set chart type
            SetPlotType();
            _chart.EndUpdate();

            // force chart repainting
            _chart.Refresh();
        }

        public void Create(double[] xs, double[] ys)
        {
            throw new NotImplementedException();
        }

        public string GetInfo()
        {
            return string.Format("{0} {1}", GetName(), _chart.GetType().Assembly.GetName().Version);
        }

        public virtual string GetName()
        {
            return "FlexChart";
        }

        public object GetControl()
        {
            return _chart;
        }
    }

    class FlexChartDxCtrl : FlexChartCtrl
    {
        protected override FlexChart CreateChart()
        {
            var chart = base.CreateChart();
            chart.RenderMode = RenderMode.DirectX;
            return chart;
        }

        public override string GetName()
        {
            return "FlexChartDX";
        }
    }
}
